#
# spec file for package ghc-network
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name network
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        2.8.0.0
Release:        1.2
Summary:        Low-level networking interface
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-unix-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
This package provides a low-level networking interface.

In network-2.6 the 'Network.URI' module was split off into its own package,
network-uri-2.6. If you're using the 'Network.URI' module you can automatically
get it from the right package by adding this to your .cabal file:

> library > build-depends: network-uri-flag.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md examples

%changelog
* Mon Nov 19 2018 psimons@suse.com
- Update network to version 2.8.0.0.
  [#]# Version 2.8.0.0
  * Breaking change: PortNumber originally contained Word32 in network
    byte order and used "deriving Ord". This results in strange behavior
    on the Ord instance. Now PortNumber holds Word32 in host byte order.
    [#347](https://github.com/haskell/network/pull/347)
  * Breaking change: stopping the export of the PortNum constructor in
    PortNumber.
  * Use bytestring == 0.10.* only.
  * Use base >= 4.7 && < 5.
* Thu Oct  4 2018 psimons@suse.com
- Update network to version 2.7.0.2.
  * Removing withMVar to avoid the deadlock between "accept" and "close"
    [#330](https://github.com/haskell/network/pull/330)
  * "close" does not throw exceptions. A new API: "close'" throws
    exceptions when necessary.
    [#337](https://github.com/haskell/network/pull/337)
  * Fixing the hang of lazy sendAll.
    [#340](https://github.com/haskell/network/pull/340)
  * Installing NetDef.h (#334)
    [#334](https://github.com/haskell/network/pull/334)
  * A new API: socketPortSafe.
    [#319](https://github.com/haskell/network/pull/319)
  * Fixing a drain bug of sendAll.
    [#320](https://github.com/haskell/network/pull/320)
  * Porting the new CALLCONV convention from master.
    [#313](https://github.com/haskell/network/pull/313)
  * Withdrawing the deprecations of packFamily and unpackFamily.
    [#324](https://github.com/haskell/network/pull/324)
  * Obsoleting the Network module.
  * Obsoleting the Network.BSD module.
  * Obsoleting APIs: MkSocket, htonl, ntohl,
  getPeerCred, getPeerEid,
  send, sendTo, recv, recvFrom, recvLen,
  inet_addr, inet_ntoa,
  isConnected, isBound, isListening, isReadable, isWritable,
  aNY_PORT, iNADDR_ANY, iN6ADDR_ANY, sOMAXCONN,
  sOL_SOCKET, sCM_RIGHTS,
  packFamily, unpackFamily, packSocketType
  * Do not closeFd within sendFd.
    [#271](https://github.com/haskell/network/pull/271)
  * Exporting ifNameToIndex and ifIndexToName from Network.Socket.
  * New APIs: setCloseOnExecIfNeeded, getCloseOnExec and getNonBlock
  * New APIs: isUnixDomainSocketAvailable and getPeerCredential
  * socketPair, sendFd and recvFd are exported even on Windows.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Fri Jul 13 2018 psimons@suse.com
- Update network to version 2.6.3.6.
  [#]# Version 2.6.3.6
  * Removed unnecessary withMVar, which caused locking on close.
    [#330](https://github.com/haskell/network/pull/330)
* Mon May 14 2018 psimons@suse.com
- Update network to version 2.6.3.5.
  * Reverting "Do not closeFd within sendFd"
  [#271](https://github.com/haskell/network/pull/271)
  * Don't touch IPv6Only when running on OpenBSD
  [#227](https://github.com/haskell/network/pull/227)
  * Do not closeFd within sendFd
  [#271](https://github.com/haskell/network/pull/271)
  * Updating examples and docs.
  * Adds a function to show the defaultHints without reading their undefined fields
  [#291](https://github.com/haskell/network/pull/291)
  * Improve exception error messages for getAddrInfo and getNameInfo
  [#289](https://github.com/haskell/network/pull/289)
  * Deprecating SockAddrCan.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 2.6.3.2 revision 1.
* Wed Aug 17 2016 psimons@suse.com
- Update to version 2.6.3.1 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 2.6.2.1 revision 0 with cabal2obs.
* Mon Jul 13 2015 mimi.vx@gmail.com
- update to 2.6.2.1
  * Regenerate configure and HsNetworkConfig.h.in.
  * Better detection of CAN sockets.
  * Add support for TCP_USER_TIMEOUT.
  * Don't conditionally export the SockAddr constructors.
  * Add isSupportSockAddr to allow checking for supported
  address types at runtime.
* Sun May 31 2015 mimi.vx@gmail.com
- update to 2.6.2.0
  * no upstream changelog
* Sun May 10 2015 mimi.vx@gmail.com
- update to 2.6.1.0
  * no upstream changelog
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 2.6.0.2
  * split to network and network-uri packages
* Fri Sep 12 2014 peter.trommler@ohm-hochschule.de
- update to 2.4.2.3
  * no changelog
  * Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- regenerate spec file
* Sat Aug 23 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Mon May  6 2013 peter.trommler@ohm-hochschule.de
- update to 2.4.1.2 from upstream
  * no changelog
  * see https://github.com/haskell/network for commit messages
- update needed for Haskell Platform 2013.2
- more transparent packaging (fewer macros)
* Mon Jan  7 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag to help source validator
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- make service localonly for Factory submission
* Wed Oct  3 2012 peter.trommler@ohm-hochschule.de
- downgrade to 2.3.1.0 for Haskell Platform 2012.4.0.0
  * cabal-install requires < 2.4
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- update to 2.4.0.1 from upstream
- required by Haskell Platform 2012.4.0.0
* Sun Jun  3 2012 peter.trommler@ohm-hochschule.de
- update to 2.3.0.13 from upstream
  * Add Num constraint to packBits, unpackBits
  * Turn off some build warnings
  * Network.URI: remove dropHead, use 'drop 1'
- spec file template generated by cabal2spec-0.25.5
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Adjusted version for platform 2011.4
* Wed Dec 14 2011 peter.trommler@ohm-hochschule.de
- Fix defattr
* Wed Dec 14 2011 peter.trommler@ohm-hochschule.de
- Added rpmlintrc and BR ghc libraries
* Tue Nov  1 2011 peter.trommler@ohm-hochschule.de
- Initial packaging.
